class HotLoadAmmoReplace extends X2Ability 
	dependson (XComGameStateContext_Ability) config (Ammo);

var config bool SECONDARY_USE_PRIMARY_AMMO;

static function array<X2DataTemplate> CreateTemplates()
{
	local array<X2DataTemplate> Templates;

	Templates.AddItem(HotLoadAmmo());

	return Templates;	
}

static function X2DataTemplate HotLoadAmmo()
{
	local X2AbilityTemplate                 Template;
	local X2AbilityTrigger_UnitPostBeginPlay PostBeginPlayTrigger;

	`CREATE_X2ABILITY_TEMPLATE(Template, 'HotLoadAmmo');

	Template.bDontDisplayInAbilitySummary = true;
	Template.AbilityToHitCalc = default.DeadEye;

	Template.AbilityTargetStyle = default.SelfTarget;

	PostBeginPlayTrigger = new class'X2AbilityTrigger_UnitPostBeginPlay';
	PostBeginPlayTrigger.Priority -= 10;        // Lower priority to guarantee ammo modifying effects (e.g. Deep Pockets) already run.
	Template.AbilityTriggers.AddItem(PostBeginPlayTrigger);

	Template.AbilitySourceName = 'eAbilitySource_Standard';
	Template.eAbilityIconBehaviorHUD = eAbilityIconBehavior_NeverShow;
	Template.Hostility = eHostility_Neutral;

	Template.BuildNewGameStateFn = HotLoadAmmo_BuildGameState;
	Template.BuildVisualizationFn = none;

	Template.bDisplayInUITooltip = false;
	Template.bDisplayInUITacticalText = false;

	return Template;
}

simulated function XComGameState HotLoadAmmo_BuildGameState(XComGameStateContext Context)
{
	local XComGameState NewGameState;
	local XComGameState_Unit UnitState;
	local XComGameStateContext_Ability AbilityContext;
	local XComGameState_Ability AbilityState;
	local XComGameState_Item AmmoState, WeaponState, NewWeaponState, OtherWeaponState;
	local array<XComGameState_Item> UtilityItems;
	local array<X2WeaponUpgradeTemplate> TemplateList;
	local X2AmmoTemplate AmmoTemplate;
	local X2WeaponTemplate WeaponTemplate;
	local X2WeaponUpgradeTemplate WeaponUpgradeTemplate;
	local X2WeaponUpgradeTemplate_Ammo UpgradedAmmo;
	local name Ability;
	local bool FoundAmmo;


	NewGameState = `XCOMHISTORY.CreateNewGameState(true, Context);
	AbilityContext = XComGameStateContext_Ability(Context);
	AbilityState = XComGameState_Ability(`XCOMHISTORY.GetGameStateForObjectID(AbilityContext.InputContext.AbilityRef.ObjectID));

	UnitState = XComGameState_Unit(NewGameState.CreateStateObject(class'XComGameState_Unit', AbilityContext.InputContext.SourceObject.ObjectID));
	WeaponState = AbilityState.GetSourceWeapon();
	NewWeaponState = XComGameState_Item(NewGameState.CreateStateObject(class'XComGameState_Item', WeaponState.ObjectID));
	WeaponTemplate = X2WeaponTemplate(WeaponState.GetMyTemplate());

	UtilityItems = UnitState.GetAllItemsInSlot(eInvSlot_Utility);
	foreach UtilityItems(AmmoState)
	{
		AmmoTemplate = X2AmmoTemplate(AmmoState.GetMyTemplate());
		if (AmmoTemplate != none && AmmoTemplate.IsWeaponValidForAmmo(WeaponTemplate))
		{
			FoundAmmo = true;
			break;
		}
	}
	if (FoundAmmo)
	{
		NewWeaponState.LoadedAmmo = AmmoState.GetReference();
		NewWeaponState.Ammo += AmmoState.GetClipSize();
		NewGameState.AddStateObject(UnitState);
	}
	else
	{
		OtherWeaponState = UnitState.GetSecondaryWeapon();
		TemplateList = WeaponState.GetMyWeaponUpgradeTemplates();
		NewGameState.AddStateObject(UnitState);
		foreach TemplateList(WeaponUpgradeTemplate)
		{
			UpgradedAmmo = X2WeaponUpgradeTemplate_Ammo(WeaponUpgradeTemplate);
			if (UpgradedAmmo != none)
			{
				FoundAmmo = true;
				AmmoState = UpgradedAmmo.AmmoTemplate.CreateInstanceFromTemplate(NewGameState);
				NewGameState.AddStateObject(AmmoState);
				NewWeaponState.LoadedAmmo = AmmoState.GetReference();
				NewWeaponState.Ammo += AmmoState.GetClipSize();

				// Check if secondary weapon is not current weapon
				// Also check if secondary weapons should copy primary weapon ammo
				if (OtherWeaponstate.GetReference().ObjectID != WeaponState.GetReference().ObjectID && SECONDARY_USE_PRIMARY_AMMO && CanLoadAmmo(OtherWeaponState))
				{
					OtherWeaponState = XComGameState_Item(NewGameState.CreateStateObject(class'XComGameState_Item', OtherWeaponState.ObjectID));
					// Give ammo to secondary weapon
					OtherWeaponState.LoadedAmmo = AmmoState.GetReference();
					OtherWeaponState.Ammo += AmmoState.GetClipSize();
					NewGameState.AddStateObject(OtherWeaponState);
				}

				foreach UpgradedAmmo.Abilities(Ability)
				{
					EnsureAbilityOnUnit(UnitState, Ability, NewGameState, AmmoState.GetReference(), AmmoState.GetReference());
				}

				break;
			}
		}
	}
	
	NewGameState.AddStateObject(NewWeaponState);

	return NewGameState;
}

function bool CanLoadAmmo(XComGameState_Item Weapon)
{
	local X2EquipmentTemplate       EquipmentTemplate; 
	local name                      AbilityName;

	if (Weapon.HasLoadedAmmo())
	{
		// Already has ammo
		return false;
	}

	EquipmentTemplate = X2EquipmentTemplate(Weapon.GetMyTemplate());

	foreach EquipmentTemplate.Abilities(AbilityName)
	{
		if (AbilityName == 'HotLoadAmmo')
		{
			return true;
		}
	}
	return false;
}

// Ensure the unit represented by the given reference has the EvacAll ability
function EnsureAbilityOnUnit(XComGameState_Unit UnitState, name Ability, XComGameState NewGameState, optional StateObjectReference ItemRef, optional StateObjectReference AmmoRef)
{
	local XComGameState_Unit NewUnitState;
	local X2AbilityTemplateManager AbilityTemplateManager;
	local X2AbilityTemplate AbilityTemplate;
	local XComGameState_Ability AbilityState;
	local StateObjectReference StateObjectRef;

	// Loop over all the abilities they have
	foreach UnitState.Abilities(StateObjectRef) 
	{
		AbilityState = XComGameState_Ability(`XCOMHISTORY.GetGameStateForObjectID(StateObjectRef.ObjectID));

		// If the unit already has this ability, don't add a new one.
		if (AbilityState.GetMyTemplateName() == Ability)
		{
			return;
		}
	}
	
	AbilityTemplateManager = class'X2AbilityTemplateManager'.static.GetAbilityTemplateManager();
	AbilityTemplate = AbilityTemplateManager.FindAbilityTemplate(Ability);
	
	NewUnitState = XComGameState_Unit(NewGameState.CreateStateObject(class'XComGameState_Unit', UnitState.ObjectID));
	AbilityState = AbilityTemplate.CreateInstanceFromTemplate(NewGameState);
	AbilityState.SourceWeapon = ItemRef;
	AbilityState.SourceAmmo = AmmoRef;
	AbilityState.InitAbilityForUnit(NewUnitState, NewGameState);
	NewGameState.AddStateObject(AbilityState);
	NewUnitState.Abilities.AddItem(AbilityState.GetReference());
	NewGameState.AddStateObject(NewUnitState);
}