class X2WeaponUpgradeTemplate_Ammo extends X2WeaponUpgradeTemplate;

var X2AmmoTemplate	AmmoTemplate;
var array<name>		Abilities;  

var config array<name> MutualExclusiveUpgrades;
var config array<name> WeaponFallbacks;

static function X2WeaponUpgradeTemplate_Ammo CreateAmmoUpgrade(Name TemplateName, X2AmmoTemplate Ammo)
{
	local X2WeaponUpgradeTemplate_Ammo Template;
	local string IconLoc;
	local name ability;

	local name weaponFallback;
	local name exclusiveUpgrade;

	`CREATE_X2TEMPLATE(class'X2WeaponUpgradeTemplate_Ammo', Template, TemplateName);
	Template.AmmoTemplate = Ammo;
	
	Template.CanApplyUpgradeToWeaponFn = CanApplyAmmoUpgradeToWeapon;
	
	Template.CanBeBuilt = false;
	Template.MaxQuantity = 1;

	Template.BlackMarketTexts = class'X2Item_DefaultUpgrades'.default.UpgradeBlackMarketTexts;

	Template.MutuallyExclusiveUpgrades.AddItem('TracerRoundsUpgrade');
	Template.MutuallyExclusiveUpgrades.AddItem('APRoundsUpgrade');
	Template.MutuallyExclusiveUpgrades.AddItem('IncendiaryRoundsUpgrade');
	Template.MutuallyExclusiveUpgrades.AddItem('TalonRoundsUpgrade');
	Template.MutuallyExclusiveUpgrades.AddItem('VenomRoundsUpgrade');
	Template.MutuallyExclusiveUpgrades.AddItem('BluescreenRoundsUpgrade');

	foreach default.MutualExclusiveUpgrades(exclusiveUpgrade)
	{
		Template.MutuallyExclusiveUpgrades.AddItem(exclusiveUpgrade);
	}

	Template.TradingPostValue = Ammo.TradingPostValue;
	Template.Tier = Ammo.Tier;
	Template.PointsToComplete = Ammo.PointsToComplete;
	
	

	// Copying localization texts from ammo
	Template.FriendlyName = Ammo.FriendlyName;
	Template.FriendlyNamePlural = Ammo.FriendlyNamePlural;
	Template.TacticalText = Ammo.TacticalText;
	Template.BriefSummary = Ammo.BriefSummary;

	foreach Ammo.Abilities(ability)
	{
		Template.Abilities.AddItem(ability);
	}

	IconLoc = Ammo.strImage;

	Template.strImage = IconLoc;

	Template.AddUpgradeAttachment('', 'UIPawnLocation_WeaponUpgrade_AssaultRifle_Suppressor', "", "", 'AssaultRifle_CV', , "", IconLoc, "img:///UILibrary_StrategyImages.X2InventoryIcons.Inv_weaponIcon_clip");
	Template.AddUpgradeAttachment('', 'UIPawnLocation_WeaponUpgrade_AssaultRifle_Suppressor', "", "", 'AssaultRifle_MG', , "", IconLoc, "img:///UILibrary_StrategyImages.X2InventoryIcons.Inv_weaponIcon_clip");
	Template.AddUpgradeAttachment('', 'UIPawnLocation_WeaponUpgrade_AssaultRifle_Suppressor', "", "", 'AssaultRifle_BM', , "", IconLoc, "img:///UILibrary_StrategyImages.X2InventoryIcons.Inv_weaponIcon_clip");

	Template.AddUpgradeAttachment('', 'UIPawnLocation_WeaponUpgrade_Shotgun_Suppressor', "", "", 'Shotgun_CV', , "", IconLoc, "img:///UILibrary_StrategyImages.X2InventoryIcons.Inv_weaponIcon_clip");
	Template.AddUpgradeAttachment('', 'UIPawnLocation_WeaponUpgrade_Shotgun_Suppressor', "", "", 'Shotgun_MG', , "", IconLoc, "img:///UILibrary_StrategyImages.X2InventoryIcons.Inv_weaponIcon_clip");
	Template.AddUpgradeAttachment('', 'UIPawnLocation_WeaponUpgrade_Shotgun_Suppressor', "", "", 'Shotgun_BM', , "", IconLoc, "img:///UILibrary_StrategyImages.X2InventoryIcons.Inv_weaponIcon_clip");

	Template.AddUpgradeAttachment('', 'UIPawnLocation_WeaponUpgrade_Sniper_Suppressor', "", "", 'SniperRifle_CV', , "", IconLoc, "img:///UILibrary_StrategyImages.X2InventoryIcons.Inv_weaponIcon_clip");
	Template.AddUpgradeAttachment('', 'UIPawnLocation_WeaponUpgrade_Sniper_Suppressor', "", "", 'SniperRifle_MG', , "", IconLoc, "img:///UILibrary_StrategyImages.X2InventoryIcons.Inv_weaponIcon_clip");
	Template.AddUpgradeAttachment('', 'UIPawnLocation_WeaponUpgrade_Sniper_Suppressor', "", "", 'SniperRifle_BM', , "", IconLoc, "img:///UILibrary_StrategyImages.X2InventoryIcons.Inv_weaponIcon_clip");

	Template.AddUpgradeAttachment('', 'UIPawnLocation_WeaponUpgrade_Cannon_Suppressor', "", "", 'Cannon_CV', , "", IconLoc, "img:///UILibrary_StrategyImages.X2InventoryIcons.Inv_weaponIcon_clip");
	Template.AddUpgradeAttachment('', 'UIPawnLocation_WeaponUpgrade_Cannon_Suppressor', "", "", 'Cannon_MG', , "", IconLoc, "img:///UILibrary_StrategyImages.X2InventoryIcons.Inv_weaponIcon_clip");
	Template.AddUpgradeAttachment('', 'UIPawnLocation_WeaponUpgrade_Cannon_Suppressor', "", "", 'Cannon_BM', , "", IconLoc, "img:///UILibrary_StrategyImages.X2InventoryIcons.Inv_weaponIcon_clip");
	
	foreach default.WeaponFallbacks(weaponFallback)
	{
		Template.AddUpgradeAttachment('', 'UIPawnLocation_WeaponUpgrade_Cannon_Suppressor', "", "", weaponFallback, , "", IconLoc, "img:///UILibrary_StrategyImages.X2InventoryIcons.Inv_weaponIcon_clip");
	}

	Template.RewardDecks.AddItem('ExperimentalAmmoUpgradeRewards');

	return Template;
}

static function bool CanApplyAmmoUpgradeToWeapon(X2WeaponUpgradeTemplate UpgradeTemplate, XComGameState_Item Weapon, int SlotIndex)
{
	local array<X2WeaponUpgradeTemplate> AttachedUpgradeTemplates;
	local X2WeaponUpgradeTemplate AttachedUpgrade; 
	local int iSlot;
		
	AttachedUpgradeTemplates = Weapon.GetMyWeaponUpgradeTemplates();

	foreach AttachedUpgradeTemplates(AttachedUpgrade, iSlot)
	{
		// Slot Index indicates the upgrade slot the player intends to replace with this new upgrade
		if (iSlot == SlotIndex)
		{
			// The exact upgrade already equipped in a slot cannot be equipped again
			// This allows different versions of the same upgrade type to be swapped into the slot
			if (AttachedUpgrade == UpgradeTemplate)
			{
				return false;
			}
		}
		else if (UpgradeTemplate.MutuallyExclusiveUpgrades.Find(AttachedUpgrade.Name) != INDEX_NONE)
		{
			// If the new upgrade is mutually exclusive with any of the other currently equipped upgrades, it is not allowed
			return false;
		}
	}

	return true;
}

DefaultProperties
{
	ItemCat="ammo"
}